@@ -11,7 +11,7 @@ from djangotribune.settings_local import TRIBUNE_SMILEYS_URL
 POST_CLEANER_TAG_RE = '<(?P<tag>/?(?:b|i|s|u|tt|m|code))>'
 POST_CLEANER_SCHEME_RE = '(?P<scheme>(?:http|ftp|https|chrome|gopher|git|git+ssh|svn|svn+ssh)://)'
 POST_CLEANER_CLOCK_RE = u'(?<![0-9])(?P<clock>(?P<h>2[0-3]|[01][0-9])(?P<c>(?=[0-5][0-9][:0-9])|:)(?P<m>[0-5][0-9])(?:(?P=c)(?P<s>[0-5][0-9])(?:(?P<sel>[¹²³⁴⁵⁶⁷⁸⁹][⁰¹²³⁴⁵⁶⁷⁸⁹]?|[\^:][1-9][0-9]?))?)?)(?![0-9:@])'
-POST_CLEANER_TOTOZ_RE = '(?P<totoz>\[\:[A-Za-z0-9-_ ]+\])'
+POST_CLEANER_TOTOZ_RE = '(?P<totoz>\[\:[A-Za-z0-9-_@ ]+(?:\:[0-9]+)?\])'
 POST_CLEANER_RE = re.compile('(' + POST_CLEANER_TOTOZ_RE + '|(?P<sep>[\(\)\[\]"])|' + POST_CLEANER_TAG_RE + '|' + POST_CLEANER_SCHEME_RE + '|' + POST_CLEANER_CLOCK_RE + ')')
 POST_CLEANER_SEP_END = { '(': ')', '[': ']', '"': '"' }
 
@@ -205,7 +205,8 @@ class PostCleaner(GenericPostCleaner):
         self.link_rel_escape = link_rel_escape
 
     def append_escape(self, s):
-        self.append(XmlEntities(s))
+        #self.append(XmlEntities(s))
+        self.append(s)
 
     def append_url(self, scheme, url): # scheme includes ://
         self.append('<a href="')
@@ -295,7 +296,7 @@ class MessageParser(object):
                     totoz = chunk[13:-4]
                     totoz_url = self.smileys_url.format(totoz)
                     slipped_web.write('<a class="smiley" href="%s" rel="nofollow">[:%s]</a>' % (totoz_url, totoz))
-                    slipped_remote.write('<a href="%s" class="smiley">[:%s]</a>' % (totoz_url, totoz))
+                    slipped_remote.write('[:%s]'%totoz)
                 else:
                     slipped_web.write(chunk)
                     slipped_remote.write(chunk)
@@ -312,7 +313,7 @@ class MessageParser(object):
         }
         
     def validate(self, source):
-        ## TODO: invalid for words with a crazy length
+        ## TODO: invalidate for words with a crazy length
         #if len(source.strip()) < self.min_width:
             #return False
         return True
